@@ -1,7 +1,7 @@
 // samplv1_config.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -311,13 +311,14 @@ void samplv1_config::load (void)
 	sPresetDir = QSettings::value("/PresetDir").toString();
 	sSampleDir = QSettings::value("/SampleDir").toString();
 	iKnobDialMode = QSettings::value("/KnobDialMode", 0).toInt();
+	iKnobEditMode = QSettings::value("/KnobEditMode", 0).toInt();
 	bControlsEnabled = QSettings::value("/ControlsEnabled", false).toBool();
 	bProgramsEnabled = QSettings::value("/ProgramsEnabled", false).toBool();
 	QSettings::endGroup();
 
 	QSettings::beginGroup("/Dialogs");
 	bProgramsPreview = QSettings::value("/ProgramsPreview", false).toBool();
-	bUseNativeDialogs = QSettings::value("/UseNativeDialogs", true).toBool();
+	bUseNativeDialogs = QSettings::value("/UseNativeDialogs", false).toBool();
 	// Run-time special non-persistent options.
 	bDontUseNativeDialogs = !bUseNativeDialogs;
 	QSettings::endGroup();
@@ -339,6 +340,7 @@ void samplv1_config::save (void)
 	QSettings::setValue("/PresetDir", sPresetDir);
 	QSettings::setValue("/SampleDir", sSampleDir);
 	QSettings::setValue("/KnobDialMode", iKnobDialMode);
+	QSettings::setValue("/KnobEditMode", iKnobEditMode);
 	QSettings::setValue("/ControlsEnabled", bControlsEnabled);
 	QSettings::setValue("/ProgramsEnabled", bProgramsEnabled);
 	QSettings::endGroup();
@@ -357,3 +359,4 @@ void samplv1_config::save (void)
 
 
 // end of samplv1_config.cpp
+
