@@ -1,7 +1,7 @@
 // samplv1_param.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -94,7 +94,7 @@ struct ParamInfo {
 	{ "DEF1_PRESSURE", PARAM_FLOAT,   0.2f,   0.0f,   1.0f }, // DEF1 Pressure
 	{ "DEF1_VELOCITY", PARAM_FLOAT,   0.2f,   0.0f,   1.0f }, // DEF1 Velocity
 	{ "DEF1_CHANNEL",  PARAM_INT,     0.0f,   0.0f,  16.0f }, // DEF1 Channel
-	{ "DEF1_MONO",     PARAM_BOOL,    0.0f,   0.0f,   1.0f }, // DEF1 Mono
+	{ "DEF1_MONO",     PARAM_INT,     0.0f,   0.0f,   2.0f }, // DEF1 Mono
 
 	{ "CHO1_WET",      PARAM_FLOAT,   0.0f,   0.0f,   1.0f }, // Chorus Wet
 	{ "CHO1_DELAY",    PARAM_FLOAT,   0.5f,   0.0f,   1.0f }, // Chorus Delay
@@ -177,7 +177,6 @@ void samplv1_param::loadSamples (
 				if (eChild.isNull())
 					continue;
 				if (eChild.tagName() == "filename") {
-				//	int index = eSample.attribute("index").toInt();
 					sFilename = eChild.text();
 				}
 				else
@@ -193,8 +192,8 @@ void samplv1_param::loadSamples (
 			if (sFilename.isEmpty())
 				sFilename = eSample.text();
 			// Done it.
-			sFilename = QFileInfo(sFilename).canonicalFilePath();
-			pSampl->setSampleFile(sFilename.toUtf8().constData());
+			pSampl->setSampleFile(
+				QFileInfo(sFilename).canonicalFilePath().toUtf8().constData());
 			// Set actual sample loop points...
 			pSampl->setLoopRange(iLoopStart, iLoopEnd);
 		}
@@ -203,7 +202,7 @@ void samplv1_param::loadSamples (
 
 
 void samplv1_param::saveSamples (
-	samplv1 *pSampl, QDomDocument& doc, QDomElement& eSamples )
+	samplv1 *pSampl, QDomDocument& doc, QDomElement& eSamples, bool bSymLink )
 {
 	if (pSampl == NULL)
 		return;
@@ -212,14 +211,25 @@ void samplv1_param::saveSamples (
 	if (pszSampleFile == NULL)
 		return;
 
+	QFileInfo fi(QString::fromUtf8(pszSampleFile));
+	if (bSymLink) {
+		const QString& sPath = fi.absoluteFilePath();
+		const QString& sName = fi.baseName();
+		const QString& sExt  = fi.completeSuffix();
+		const QString& sLink = sName
+			+ '-' + QString::number(qHash(sPath), 16)
+			+ '.' + sExt;
+		QFile(sPath).link(sLink);
+		fi.setFile(QDir::current(), sLink);
+	}
+
 	QDomElement eSample = doc.createElement("sample");
 	eSample.setAttribute("index", 0);
 	eSample.setAttribute("name", "GEN1_SAMPLE");
 
 	QDomElement eFilename = doc.createElement("filename");
 	eFilename.appendChild(doc.createTextNode(
-		QDir::current().relativeFilePath(
-			QString::fromUtf8(pszSampleFile))));
+		QDir::current().relativeFilePath(fi.absoluteFilePath())));
 	eSample.appendChild(eFilename);
 
 	const uint32_t iLoopStart = pSampl->loopStart();
@@ -263,10 +273,11 @@ bool samplv1_param::paramFloat ( samplv1::ParamIndex index )
 
 
 // Preset serialization methods.
-void samplv1_param::loadPreset ( samplv1 *pSampl, const QString& sFilename )
+bool samplv1_param::loadPreset (
+	samplv1 *pSampl, const QString& sFilename )
 {
 	if (pSampl == NULL)
-		return;
+		return false;
 
 	QFileInfo fi(sFilename);
 	if (!fi.exists()) {
@@ -275,16 +286,16 @@ void samplv1_param::loadPreset ( samplv1 *pSampl, const QString& sFilename )
 			const QString& sPresetFile
 				= pConfig->presetFile(sFilename);
 			if (sPresetFile.isEmpty())
-				return;
+				return false;
 			fi.setFile(sPresetFile);
 			if (!fi.exists())
-				return;
+				return false;
 		}
 	}
 
 	QFile file(fi.filePath());
 	if (!file.open(QIODevice::ReadOnly))
-		return;
+		return false;
 
 	static QHash<QString, samplv1::ParamIndex> s_hash;
 	if (s_hash.isEmpty()) {
@@ -342,13 +353,16 @@ void samplv1_param::loadPreset ( samplv1 *pSampl, const QString& sFilename )
 	pSampl->reset();
 
 	QDir::setCurrent(currentDir.absolutePath());
+
+	return true;
 }
 
 
-void samplv1_param::savePreset ( samplv1 *pSampl, const QString& sFilename )
+bool samplv1_param::savePreset (
+	samplv1 *pSampl, const QString& sFilename, bool bSymLink )
 {
 	if (pSampl == NULL)
-		return;
+		return false;
 
 	const QFileInfo fi(sFilename);
 	const QDir currentDir(QDir::current());
@@ -360,7 +374,7 @@ void samplv1_param::savePreset ( samplv1 *pSampl, const QString& sFilename )
 	ePreset.setAttribute("version", CONFIG_BUILD_VERSION);
 
 	QDomElement eSamples = doc.createElement("samples");
-	samplv1_param::saveSamples(pSampl, doc, eSamples);
+	samplv1_param::saveSamples(pSampl, doc, eSamples, bSymLink);
 	ePreset.appendChild(eSamples);
 
 	QDomElement eParams = doc.createElement("params");
@@ -377,12 +391,15 @@ void samplv1_param::savePreset ( samplv1 *pSampl, const QString& sFilename )
 	doc.appendChild(ePreset);
 
 	QFile file(fi.filePath());
-	if (file.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
-		QTextStream(&file) << doc.toString();
-		file.close();
-	}
+	if (!file.open(QIODevice::WriteOnly | QIODevice::Truncate))
+		return false;
+
+	QTextStream(&file) << doc.toString();
+	file.close();
 
 	QDir::setCurrent(currentDir.absolutePath());
+
+	return true;
 }
 
 
