@@ -1,7 +1,7 @@
 // samplv1_param.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -41,13 +41,15 @@ namespace samplv1_param
 	void loadSamples(samplv1 *pSampl,
 		const QDomElement& eSamples);
 	void saveSamples(samplv1 *pSampl,
-		QDomDocument& doc, QDomElement& eSamples);
+		QDomDocument& doc, QDomElement& eSamples,
+		bool bSymLink = false);
 
 	// Preset serialization methods.
-	void loadPreset(samplv1 *pSampl,
-		const QString& sFilename);
-	void savePreset(samplv1 *pSampl,
+	bool loadPreset(samplv1 *pSampl,
 		const QString& sFilename);
+	bool savePreset(samplv1 *pSampl,
+		const QString& sFilename,
+		bool bSymLink = false);
 
 	// Default parameter name/value helpers.
 	const char *paramName(samplv1::ParamIndex index);
