@@ -230,41 +230,52 @@ void samplv1widget_preset::openPreset (void)
 	if (pConfig == NULL)
 		return;
 
-	QString sFilename;
+	QStringList files;
 
 	const QString  sExt(SAMPLV1_TITLE);
 	const QString& sTitle  = tr("Open Preset") + " - " SAMPLV1_TITLE;
 	const QString& sFilter = tr("Preset files (*.%1)").arg(sExt);
-#if 1//QT_VERSION < 0x040400
+
+	QWidget *pParentWidget = NULL;
 	QFileDialog::Options options = 0;
-	if (pConfig->bDontUseNativeDialogs)
+	if (pConfig->bDontUseNativeDialogs) {
 		options |= QFileDialog::DontUseNativeDialog;
-	sFilename = QFileDialog::getOpenFileName(parentWidget(),
+		pParentWidget = parentWidget();
+	}
+#if 1//QT_VERSION < 0x040400
+	files = QFileDialog::getOpenFileNames(pParentWidget,
 		sTitle, pConfig->sPresetDir, sFilter, NULL, options);
 #else
-	QFileDialog fileDialog(nativeParentWidget(),
+	QFileDialog fileDialog(pParentWidget,
 		sTitle, pConfig->sPresetDir, sFilter);
 	fileDialog.setAcceptMode(QFileDialog::AcceptOpen);
-	fileDialog.setFileMode(QFileDialog::ExistingFile);
+	fileDialog.setFileMode(QFileDialog::ExistingFiles);
 	fileDialog.setDefaultSuffix(sExt);
 	QList<QUrl> urls(fileDialog.sidebarUrls());
 	urls.append(QUrl::fromLocalFile(pConfig->sPresetDir));
 	fileDialog.setSidebarUrls(urls);
-	if (pConfig->bDontUseNativeDialogs)
-		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
+	fileDialog.setOptions(options);
 	if (fileDialog.exec())
-		sFilename = fileDialog.selectedFiles().first();
+		files = fileDialog.selectedFiles();
 #endif
-	if (!sFilename.isEmpty()) {
-		QFileInfo fi(sFilename);
-		if (fi.exists() && queryPreset()) {
-			const QString& sPreset = fi.completeBaseName();
-			pConfig->setPresetFile(sPreset, sFilename);
-			emit loadPresetFile(sFilename);
-			++m_iInitPreset;
-		//	pConfig->sPreset = sPreset;
-			pConfig->sPresetDir = fi.absolutePath();
-			setPreset(sPreset);
+
+	if (!files.isEmpty() && queryPreset()) {
+		int iPreset = 0;
+		QStringListIterator iter(files);
+		while (iter.hasNext()) {
+			const QString& sFilename = iter.next();
+			const QFileInfo fi(sFilename);
+			if (fi.exists()) {
+				const QString& sPreset = fi.completeBaseName();
+				pConfig->setPresetFile(sPreset, sFilename);
+				if (++iPreset == 1) {
+					++m_iInitPreset;
+					emit loadPresetFile(sFilename);
+				//	pConfig->sPreset = sPreset;
+					pConfig->sPresetDir = fi.absolutePath();
+					setPreset(sPreset);
+				}
+			}
 			refreshPreset();
 		}
 	}
@@ -293,14 +304,17 @@ void samplv1widget_preset::savePreset ( const QString& sPreset )
 	if (!fi.exists()) {
 		const QString& sTitle  = tr("Save Preset") + " - " SAMPLV1_TITLE;
 		const QString& sFilter = tr("Preset files (*.%1)").arg(sExt);
-	#if 1//QT_VERSION < 0x040400
+		QWidget *pParentWidget = NULL;
 		QFileDialog::Options options = 0;
-		if (pConfig->bDontUseNativeDialogs)
+		if (pConfig->bDontUseNativeDialogs) {
 			options |= QFileDialog::DontUseNativeDialog;
-		sFilename = QFileDialog::getSaveFileName(parentWidget(),
+			pParentWidget = parentWidget();
+		}
+	#if 1//QT_VERSION < 0x040400
+		sFilename = QFileDialog::getSaveFileName(pParentWidget,
 			sTitle, sFilename, sFilter, NULL, options);
 	#else
-		QFileDialog fileDialog(nativeParentWidget(),
+		QFileDialog fileDialog(pParentWidget,
 			sTitle, sFilename, sFilter);
 		fileDialog.setAcceptMode(QFileDialog::AcceptSave);
 		fileDialog.setFileMode(QFileDialog::AnyFile);
@@ -308,8 +322,7 @@ void samplv1widget_preset::savePreset ( const QString& sPreset )
 		QList<QUrl> urls(fileDialog.sidebarUrls());
 		urls.append(QUrl::fromLocalFile(pConfig->sPresetDir));
 		fileDialog.setSidebarUrls(urls);
-		if (pConfig->bDontUseNativeDialogs)
-			fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
+		fileDialog.setOptions(options);
 		if (fileDialog.exec())
 			sFilename = fileDialog.selectedFiles().first();
 	#endif
