@@ -508,22 +508,6 @@ void samplv1widget_sample::paintEvent ( QPaintEvent *pPaintEvent )
 
     painter.fillRect(rect, rgbDark);
 
-	QString sTitle = m_sName;
-	if (m_pSample && m_pSample->filename()) {
-		if (!sTitle.isEmpty()) {
-			sTitle += ' ';
-			sTitle += '-';
-			sTitle += ' ';
-		}
-		sTitle += QFileInfo(
-			QString::fromUtf8(m_pSample->filename())
-		).completeBaseName();
-	}
-	if (!sTitle.isEmpty()) {
-		painter.setPen(pal.midlight().color());
-		painter.drawText(rect.adjusted(2, 0, -2, -0), Qt::AlignLeft, sTitle);
-	}
-
 	if (m_pSample && m_ppPolyg) {
 		const int w2 = (w << 1);
 		painter.setRenderHint(QPainter::Antialiasing, true);
@@ -547,6 +531,16 @@ void samplv1widget_sample::paintEvent ( QPaintEvent *pPaintEvent )
 			painter.fillRect(x1, 0, x2 - x1, h, grad1);
 			painter.drawLine(x1, 0, x1, h);
 			painter.drawLine(x2, 0, x2, h);
+			painter.setBrush(rgbLite);
+			QPolygon polyg(3);
+			polyg.putPoints(0, 3, x1 + 8, 0, x1, 8, x1, 0);
+			painter.drawPolygon(polyg);
+		//	polyg.putPoints(0, 3, x1 + 8, h, x1, h - 8, x1, h);
+		//	painter.drawPolygon(polyg);
+		//	polyg.putPoints(0, 3, x2 - 8, 0, x2, 8, x2, 0);
+		//	painter.drawPolygon(polyg);
+			polyg.putPoints(0, 3, x2 - 8, h, x2, h - 8, x2, h);
+			painter.drawPolygon(polyg);
 		}
 		QLinearGradient grad(0, 0, w2, h);
 		painter.setPen(bDark ? Qt::gray : Qt::darkGray);
@@ -562,6 +556,22 @@ void samplv1widget_sample::paintEvent ( QPaintEvent *pPaintEvent )
 			tr("(double-click or drop to load new sample...)"));
 	}
 
+	QString sTitle = m_sName;
+	if (m_pSample && m_pSample->filename()) {
+		if (!sTitle.isEmpty()) {
+			sTitle += ' ';
+			sTitle += '-';
+			sTitle += ' ';
+		}
+		sTitle += QFileInfo(
+			QString::fromUtf8(m_pSample->filename())
+		).completeBaseName();
+	}
+	if (!sTitle.isEmpty()) {
+		painter.setPen(pal.midlight().color());
+		painter.drawText(rect.adjusted(2, 0, -2, -0), Qt::AlignLeft, sTitle);
+	}
+
 	painter.end();
 
 	QFrame::paintEvent(pPaintEvent);
