@@ -1,7 +1,7 @@
 // samplv1widget_status.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -24,8 +24,10 @@
 
 #include <QStatusBar>
 
+
 // Forward declarations.
 class QLabel;
+class QPixmap;
 
 
 //-------------------------------------------------------------------------
@@ -40,13 +42,19 @@ public:
 	// Constructor.
 	samplv1widget_status(QWidget *pParent = 0);
 
+	// Destructor.
+	~samplv1widget_status();
+
 	// Permanent widgets accessors.
-	void setModified(bool bModified);
-	bool isModified() const;
+	void midiInLed(bool bMidiInLed);
+	void modified(bool bModified);
 
 private:
 
 	// Permanent widgets.
+	QPixmap *m_midiInLed[2];
+
+	QLabel *m_pMidiInLedLabel;
 	QLabel *m_pModifiedLabel;
 };
 
